{ config, lib, pkgs, ... }:

let
  #inherit (lib) mkIf mkMerge mkThenElse;
  cfg = config.r6d.config-generator;
  computers = config.r6d.computers;
  profiles = config.r6d.profiles;
in

{
  imports = [
    # installées systématiquement
    ./default-applications.nix
    ./environment.nix
    ./configuration/localisation.nix
    ./configuration/network.nix
    #./configuration/network-ipv6.nix
    ./configuration/udev.nix
    ./services/haveged.nix
    ./services/monitoring-munin.nix
    ./services/monitoring-smokeping.nix
    ./services/ssh.nix

    # commandées par config-generator
    ## option de configuration spécifique
    ./applications/cao.nix                   # de conception assisté par ordinateur & modélisation
    ./applications/cartographie.nix          # manipuler les données géographiques & cartes
    ./applications/developpement.nix         # développer des programmes/scripts
    ./applications/developpement-elm.nix     # développer en elm
    ./applications/developpement-haskell.nix # développer en haskell
    ./applications/developpement-java.nix    # développer en java
    ./applications/developpement-jetbrains.nix # outils jetbrains
    ./applications/developpement-rust.nix    # développer en rust
    ./applications/edition-musique.nix       # modifier les fichiers musicaux
    ./applications/edition-photo.nix         # modifier les photos & assimilé
    ./applications/edition-video.nix         # modifier les vidéos
    ./applications/jeux.nix                  # jouer, tout simplement ;)
    ./configuration/auto-upgrade.nix              # mise à jour automatique du système
    ./configuration/awesome.nix               # pour le gestionaire de fenêtres awesome
    ./configuration/laptop.nix                    # appli & configuration adaptée pour un PC portable
    ./configuration/swap.nix                      # définition de l'utilisation du swap
    ./services/print.nix                     # configuration de base de cups
    ./services/docker.nix                # activer docker
    ./services/elasticsearch.nix     # service de stockage et recher de données
    ./services/hoogle.nix            # service hoogle pour haskell
    ./services/hydra-build.nix       # service de construction de paquet. -> la machine compile des paquets
    ./services/hydra-core.nix        # service pour l'instance d'hydra
    ./services/kibana.nix            # service de visualisation de données stockées dans elasticsearch
    ./services/locate.nix            # service locate
    ./services/virtualbox.nix            # activer virtualbox
    ./services/xmonad/xmonad.nix             # pour le gestionaire de fenêtre xmonad

    ## if isDesktop
    ./applications/adminsys.nix              # pour gérer le système dans son ensemble et les services
    ./applications/bureau.nix                # éléments pour avoir un environement graphique minimal utilisable
    ./applications/bureautique.nix           # dédiée à la bureautique (traitement de texte, dessin, ...)
    ./applications/client-internet.nix       # pour accéder & utiliser des ressources par le réseau
    ./applications/multimedia.nix            # pour gérer le son, l'image et la vidéo
    ./applications/network.nix               # de gestion, de diagnostique & surveillance réseau
    ./applications/securite.nix              # relatives à la sécurité (chiffrement, gpg, mots de passe, ...)
    ./services/pulseaudio.nix        # activation du serveur audio
    ./services/scanner.nix          # utilisation d'un scanner
    ./services/x11.nix               # activation du serveur graphique X
  ];
}
